*IDENT ND_IMPLEMENTATION
*/
*/ Mod to add Neodymium isotopes (144Nd and 143Nd) to the ocean model
*/ of the FAMOUS GCM. 
*/ Surface flux from dust and rivers 
*/ Sediment source as global flux from seafloor-ocean boundary
*/ Reversible scavenging as adsorption and desorption onto 
*/ sinking particles (dust,POC,opal,CaCO3)
*/ Inserting 144Nd and 143Nd as prognostic tracers 
*/
*/ Suzanne Robinson
*/ March 2022
*/
*/
*DECLARE OTRACPNT
*/ Include pointers to TA for 144Nd and 143Nd
*I OTRACPNT.17
C Indicies for 144Nd and 143Nd
!                       ,144Nd
!                       ,143Nd
*I OTRACPNT.39
C Integer for 144Nd and 143Nd
     &       ,Nd144_TRACER
     &       ,Nd143_TRACER
*I OSY1F405.3
C COMMON/TRACPNT/T_TRACER for 144Nd and 143Nd
     &       ,Nd144_TRACER
     &       ,Nd143_TRACER
*/
*/
*DECLARE TYPPTRO
*I GRB0F304.319 
*/ Indenting in user ancillaries
      INTEGER
     &                  joc_Nd144_dust                ! Dust 144Nd flux
     &,                 joc_Nd143_dust                ! Dust 143Nd flux
     &,                 joc_Nd144_riv_conc            ! River 144Nd conc
     &,                 joc_Nd143_riv_conc            ! River 143Nd conc
     &,                 joc_Nd144_bound               ! Sediment 144Nd flux
     &,                 joc_Nd143_bound               ! Sediment 143Nd flux
     &,                 joc_r_poc                     ! R value for POC
     &,                 joc_r_caco3                   ! R value for CaCO3
     &,                 joc_r_dust                    ! R value for dust
     &,                 joc_r_opal                    ! R value for opal
*/
*I GRB0F304.324
     &,  joc_Nd144_dust,joc_Nd143_dust
     &,  joc_Nd144_riv_conc,joc_Nd143_riv_conc
     &,  joc_Nd144_bound, joc_Nd143_bound
     &,  joc_r_poc, joc_r_caco3
     &,  joc_r_dust, joc_r_opal
*/
*/
*DECLARE STOCNPT1
*I GRB4F305.508 
C Setting indices
      joc_Nd144_dust  = SI(202,0,im_index)
      joc_Nd143_dust  = SI(203,0,im_index)
      joc_Nd144_riv_conc = SI(204,0,im_index)
      joc_Nd143_riv_conc = SI(205,0,im_index)
*/
*I GRB4F305.517
      joc_Nd144_bound = SI(351,0,im_index) ! multi level
      joc_Nd143_bound = SI(352,0,im_index) ! multi level
*/
*/ R values for each sinking particle where:
*/ R= particle conc. per gridbox/1024.5
      joc_r_poc = SI(353,0,im_index) ! multi level
      joc_r_caco3 = SI(354,0,im_index) ! multi level
      joc_r_dust = SI(355,0,im_index) ! multi level
      joc_r_opal = SI(356,0,im_index) ! multi level
*/ deleted ocean multi level ancils duplicates below
*D GRB4F305.518,GRB4F305.519, GRB4F305.520, GRB4F305.521
*/
*B SI240293.20
          IF (IFLD.EQ.19) THEN    
            Nd144_TRACER = cox_tracer
          ENDIF 
          IF (IFLD.EQ.20) THEN                                                 
            Nd143_TRACER = cox_tracer
          ENDIF 
*/
*/
*DECLARE ARGOCINC
*I ARGOCINC.3
     * Nd144_dust, Nd143_dust,
     * Nd144_riv_conc, Nd143_riv_conc,
     * Nd144_bound, Nd143_bound,
     * r_poc, r_caco3,
     * r_dust, r_opal,
*/
*DECLARE TYPOCINC
*I TYPOCINC.8
     *,Nd144_dust(IMT)     ! 144Nd flux
     *,Nd143_dust(IMT)     ! 143Nd flux
     *,Nd144_riv_conc(IMT) ! 144Nd river conc (ppt)
     *,Nd143_riv_conc(IMT) ! 143Nd river conc (ppt)
     *,Nd144_river(IMT)    ! 144Nd river flux
     *,Nd143_river(IMT)    ! 143Nd river flux
     *,Nd144_bound(IMT,KM) ! 144Nd boundary source
     *,Nd143_bound(IMT,KM) ! 143Nd boundary source
     *,r_poc(IMT,KM)       ! R value for poc
     *,r_caco3(IMT,KM)     ! R value for CaCO3
     *,r_dust(IMT,KM)      ! R value for dust
     *,r_opal(IMT,KM)      ! R value for opal
     *,denominator(IMT,KM) ! Denom for rev scav
     *,multiplier(IMT,KM)  ! Mulitplier for rev scav
     *,nd144_p(IMT,KM)     ! Part associated 144Nd middle of grid
     *,nd143_p(IMT,KM)     ! Part associated 143Nd middle of grid
     *,p144_bot(IMT,KM)    ! Part associated 144Nd bottom of grid
     *,p143_bot(IMT,KM)    ! Part associated 143Nd bottom of grid
     *,p144_top(IMT,KM)    ! Part associated 144Nd top of grid
     *,p143_top(IMT,KM)    ! Part associated 143Nd top of grid
     *,nd144_sink(IMT,KM)  ! 144Nd sink from particles 
     *,nd143_sink(IMT,KM)  ! 143Nd sink from particles     
*/
*/
*DECLARE TRACER
*I OJP0F404.946   
     &,Nd144_dust,Nd143_dust
     &,Nd144_river,Nd143_river
*I OJP0F404.947  
     &,Nd144_dust,Nd143_dust
     &,Nd144_river,Nd143_river
*I RH011293.158
     &     k_poc,              ! K Poc constant
     &     k_caco3,            ! K CaCO3 constant
     &     k_dust,             ! K dust constant
     &     k_opal,             ! K opal constant
     &     rs_tune,            ! Reversible scavening tuning parameter
     &     settling_vel,       ! Uniform particle settling velocity
*/
*I TRACER.733 
*/ River outflow has a scaling factor (converting Nd ppt into g/kg)
*/ 70% of Nd from rivers removed in estuaries
*/ convert g to kg
*/ multiplied by model unit scaling factor (1E18)
         Nd144_river(I) =((( RIVER(I) * 
     &  (Nd144_riv_conc(I) * 1.0E-9)
     &   * 0.3 ) *1.0E-3) *1.0E18) 
*/
         Nd143_river(I) =((( RIVER(I) * 
     &  (Nd143_riv_conc(I) * 1.0E-9)
     &  * 0.3 ) *1.0E-3) *1.0E18) 
*/
*/
*I OJP0F404.846
C Add boundary source with timestep (s)
        DO K=1,KM                               
        DO I=1,IMT  
          TA(I,K,19)=TA(I,K,19)+(C2DTTS*Nd144_bound(I,K))
          TA(I,K,20)=TA(I,K,20)+(C2DTTS*Nd143_bound(I,K))
        ENDDO                                                            
        ENDDO
*/
*/
C REVERSIBLE SCAVENGING CODE
C Calculate particle associated 144Nd and 143Nd (kg*E18)
C rs_tune is ratio between dissolved and particulate Nd
C Used as a tuning parameter for reversible scavenging
        rs_tune=0.004
*/
C Settling velocity of 1000m/yr in 12 hr ocean timestep
         settling_vel = (1000./720.)
*/
C K value for each particle type is a constant
C K is calculated from the tuning parameter
C and R_avg (ratio of average particle conc. 
C to average density of seawater)
        k_poc = rs_tune * (1./(2.9305E-9))
        k_caco3 = rs_tune * (1./(6.2729E-9))
        k_dust = rs_tune * (1./(1.7326E-9))
        k_opal = rs_tune * (1./(5.2063E-9))
*/
        DO K=1,KM
        DO I=1,IMT
*/
          denominator(I,K) = (1.+((k_poc*r_poc(I,K))
     &    + (k_caco3*r_caco3(I,K))
     &    + (k_dust*r_dust(I,K))+(k_opal*r_opal(I,K))))
          multiplier(I,K) = (1.-(1./denominator(I,K)))
*/
C Calculate particle associated Nd per gridbox
          nd144_p(I,K)= TA(I,K,19)*multiplier(I,K)
          nd143_p(I,K)= TA(I,K,20)*multiplier(I,K)
        ENDDO                                                            
        ENDDO
*/
*/
C Calculate sink of particle associated Nd 
C Calculate sink in surface gridbox
*/
        DO I=1,IMT
*/
C Set particle Nd at surface to zero
          p144_top(I,1) = 0.0
          p143_top(I,1) = 0.0
*/
C Calculate bottom [Nd]p
*/
          p144_bot(I,1) = nd144_p(I,1) + 
     &    ( (nd144_p(I,2) - nd144_p(I,1))
     &    * ( (dz(1)/100.)*0.5) )
     &    / ( (zdzz(2)/100.) - (zdzz(1)/100.) ) 
*/
          p143_bot(I,1) = nd143_p(I,1) + 
     &    ( (nd143_p(I,2) - nd143_p(I,1))
     &    * ( (dz(1)/100.)*0.5) )
     &    / ( (zdzz(2)/100.) - (zdzz(1)/100.) )         
*/
C   Calculate the particle sink d(w*[Nd]p)/dz
          nd144_sink(I,1) = settling_vel *
     &    (p144_bot(I,1)-p144_top(I,1)) /(dz(1)/100.)
*/
          nd143_sink(I,1)= settling_vel *
     &    (p143_bot(I,1)-p143_top(I,1))/(dz(1)/100.)
*/
C Remove the Nd sink via reversible scavenging
          TA(I,1,19)= TA(I,1,19)- nd144_sink(I,1)
          TA(I,1,20)= TA(I,1,20)- nd143_sink(I,1)
        ENDDO
*/ 
C Calculate the top and bottom [Nd]p in the top gridbox
        DO I=1,IMT
        DO K=2,KMM1
C Calculate top [Nd]p
*/
          p144_top(I,K) = nd144_p(I,K-1) + 
     &    ( (nd144_p(I,K) - nd144_p(I,k-1))
     &    * ( (dz(k-1)/100.)*0.5))
     &    / ( (zdzz(k)/100.) - (zdzz(k-1)/100.))  
*/
          p143_top(I,K) = nd143_p(I,K-1) + 
     &    ( (nd143_p(I,K) - nd143_p(I,k-1))
     &    * ( (dz(k-1)/100.)*0.5))
     &    / ( (zdzz(k)/100.) - (zdzz(k-1)/100.)) 
*/
C Calculate bottom [Nd]p
*/
          p144_bot(I,K) = nd144_p(I,K) +
     &    ( (nd144_p(I,K+1) - nd144_p(I,k))
     &    * ( (dz(k)/100.)*0.5))
     &    / ((zdzz(k+1)/100.) - (zdzz(k)/100.))
*/
          p143_bot(I,K) = nd143_p(I,K) + 
     &    ( ( nd143_p(I,K+1)- nd143_p(I,k))
     &    * ( (dz(k)/100.)*0.5))
     &    / ((zdzz(k+1)/100.) - (zdzz(k)/100.))
*/
*/
*/
C   Calculate the particle sink d(w*[Nd]p)/dz
          nd144_sink(I,K) = settling_vel *
     &    (p144_bot(I,K)-p144_top(I,K))/(dz(K)/100.)
*/
          nd143_sink(I,K)= settling_vel *
     &    (p143_bot(I,K)-p143_top(I,K))/(dz(K)/100.)
*/
C Remove the Nd sink via reversible scavenging
          TA(I,K,19)= TA(I,K,19)- nd144_sink(I,K)
          TA(I,K,20)= TA(I,K,20)- nd143_sink(I,K)
*/      write(6,*) 'Sink',nd144_sink(I,K),TA(I,K,19)
        ENDDO                                                            
        ENDDO
*/
*/	
C Seafloor bottom gridbox
        DO I=1,IMT
*/
          p144_top(I,KM) = nd144_p(I,KMM1) +
     &    ( (nd144_p(I,KM)- nd144_p(I,KMM1))
     &    * ((dz(KMM1)/100.)*0.5))
     &    / ((zdzz(KM)/100.) - (zdzz(KMM1)/100.)) 
*/
          p143_top(I,KM) = nd143_p(I,KMM1) +
     &    ( (nd143_p(I,KM)- nd143_p(I,KMM1))
     &    * ( (dz(KMM1)/100.)*0.5))
     &    / ((zdzz(KM)/100.) - (zdzz(KMM1)/100.)) 
*/
*/
C Set the seafloor bottom to the concentration at the middle of gridbox
          p144_bot(I,KM) = nd144_p(I,KM)
          p143_bot(I,KM) = nd143_p(I,KM)
*/								   
C   Calculate the particle sink d(w*[Nd]p)/dz
          nd144_sink(I,KM) = (settling_vel *
     &    (p144_bot(I,KM)-p144_top(I,KM))) /(dz(KM)/100.)
          nd143_sink(I,KM)= (settling_vel *
     &    (p143_bot(I,KM)-p143_top(I,KM)))/(dz(KM)/100.)
*/
C Remove the Nd sink via reversible scavenging
          TA(I,KM,19)= TA(I,KM,19)-nd144_sink(I,KM)
          TA(I,KM,20)= TA(I,KM,20)-nd143_sink(I,KM)
*/
*/
        ENDDO                                                            
*/
*/
*DECLARE SFCADD
*I OJP0F404.949 
     &,Nd144_dust,Nd143_dust
     &,Nd144_river,Nd143_river   
*I SFCADD.68   
     &,  Nd144_dust(IMT)   ! IN flux of Nd144 from dust
     &,  Nd143_dust(IMT)   ! IN flux of Nd143 from dust
     &,  Nd144_river(IMT)  ! IN flux of Nd144 from river
     &,  Nd143_river(IMT)  ! IN flux of Nd143 from river
*I SFCADD.91
     +,  con_nd       ! Conversion factor for Nd (kg/m2/s)
*I SFCADD.104
      con_nd = 100.*(C2DTTS/DZ(1))
*I OJL1F405.7
C add surface fluxes for Nd144 (tracer 17)
C and Nd143 (tracer 18) from ancil files
C Nd144 and Nd143 had been multiplied by 1E18
      TA(i,1,19) = TA(i,1,19)+(con_nd*Nd144_dust(I))
     &             +(con_nd*Nd144_river(I))
      TA(i,1,20) = TA(i,1,20)+(con_nd*Nd143_dust(I))
     &             +(con_nd*Nd143_river(I))
*/      write(6,*) 'S4',i,Nd144_dust(i),con_nd,SFLUX(i)
*DECLARE ROWCALC
*I RH141293.12
     &     subscript,              ! Subscript Nd multi
*I OOM1F405.605
C In a loop for setting surface wind stress
        Nd144_dust(I)=D1(joc_Nd144_dust+(J-1)*IMT+I-1)
        Nd143_dust(I)=D1(joc_Nd143_dust+(J-1)*IMT+I-1)
        Nd144_riv_conc(I)=D1(joc_Nd144_riv_conc+(J-1)*IMT+I-1)
        Nd143_riv_conc(I)=D1(joc_Nd143_riv_conc+(J-1)*IMT+I-1)
*/
*I OLA3F403.228
C Loop through horizontal and depth
        DO K=1,KM 
           DO I=1,IMT
             subscript = ((k-1) * imt* jmt) + ((j-1) * imt) + i-1
             Nd144_bound(I,K) = D1(joc_Nd144_bound + subscript)
             Nd143_bound(I,K) = D1(joc_Nd143_bound + subscript)
             r_poc(I,K)=D1(joc_r_poc + subscript)
             r_caco3(I,K)=D1(joc_r_caco3 + subscript)
             r_dust(I,K)=D1(joc_r_dust + subscript)
             r_opal(I,K)=D1(joc_r_opal + subscript)                 
        ENDDO
           ENDDO
*/
*/
*/